Method: Slack::Web::Api::Endpoints::Groups#groups_list

Defined in:
lib/slack/web/api/endpoints/groups.rb

#groups_list(options = {}) ⇒ Object

This method returns a list of private channels in the team that the caller is in and archived groups that the caller was in. The list of (non-deactivated) members in each private channel is also returned.

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :exclude_archived (Object)

    Don’t return archived private channels.

See Also:



150
151
152
# File 'lib/slack/web/api/endpoints/groups.rb', line 150

def groups_list(options = {})
  post('groups.list', options)
end