Module: Slack::Web::Api::Endpoints::AppsUserConnection

Included in:
Slack::Web::Api::Endpoints
Defined in:
lib/slack/web/api/endpoints/apps_user_connection.rb

Instance Method Summary collapse

Instance Method Details

#apps_user_connection_update(options = {}) ⇒ Object

Updates the connection status between a user and an app.

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :user_id (string)

    The ID of the user for the status update.

  • :status (enum)

    The status that should be set for the user.

Raises:

  • (ArgumentError)

See Also:



18
19
20
21
22
# File 'lib/slack/web/api/endpoints/apps_user_connection.rb', line 18

def apps_user_connection_update(options = {})
  raise ArgumentError, 'Required arguments :user_id missing' if options[:user_id].nil?
  raise ArgumentError, 'Required arguments :status missing' if options[:status].nil?
  post('apps.user.connection.update', options)
end