Module: Slack::Web::Api::Endpoints::OauthV2User

Included in:
Slack::Web::Api::Endpoints
Defined in:
lib/slack/web/api/endpoints/oauth_v2_user.rb

Instance Method Summary collapse

Instance Method Details

#oauth_v2_user_access(options = {}) ⇒ Object

Exchanges a temporary OAuth verifier code for a user access token.

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :client_id (string)

    Issued when you created your application. If possible, avoid sending client_id and client_secret as parameters in your request and instead supply the Client ID and Client Secret using the HTTP Basic authentication scheme.

  • :client_secret (string)

    Issued when you created your application. If possible, avoid sending client_id and client_secret as parameters in your request and instead supply the Client ID and Client Secret using the HTTP Basic authentication scheme.

  • :code (string)

    The code param returned via the OAuth callback.

  • :code_verifier (string)

    The code_verifier param used to generate the code_challenge originally. Used for PKCE.

  • :redirect_uri (string)

    This must match the originally submitted URI (if one was sent).

  • :grant_type (string)

    The grant_type param as described in the OAuth spec.

  • :refresh_token (string)

    The refresh_token param as described in the OAuth spec.

  • :assertion (string)

    Identity assertion JWT authorization grant.

See Also:



30
31
32
# File 'lib/slack/web/api/endpoints/oauth_v2_user.rb', line 30

def oauth_v2_user_access(options = {})
  post('oauth.v2.user.access', options)
end