Module: Slack::Web::Api::Endpoints::Team

Included in:
Slack::Web::Api::Endpoints
Defined in:
lib/slack/web/api/endpoints/team.rb

Instance Method Summary collapse

Instance Method Details

#team_accessLogs(options = {}) ⇒ Object

Gets the access logs for the current team.

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :before (string)

    End of time range of logs to include in results (inclusive).

  • :team_id (string)

    encoded team id to get logs from, required if org token is used.

See Also:



18
19
20
# File 'lib/slack/web/api/endpoints/team.rb', line 18

def team_accessLogs(options = {})
  post('team.accessLogs', options)
end

#team_billableInfo(options = {}) ⇒ Object

Gets billable users information for the current team.

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :cursor (string)

    Set cursor to next_cursor returned by previous call, to indicate from where you want to list next page of users list. Default value fetches the first page.

  • :limit (integer)

    The maximum number of items to return.

  • :team_id (string)

    encoded team id to get the billable information from, required if org token is used.

  • :user (user)

    A user to retrieve the billable information for. Defaults to all users.

See Also:



35
36
37
38
39
40
41
42
43
44
# File 'lib/slack/web/api/endpoints/team.rb', line 35

def team_billableInfo(options = {})
  options = options.merge(user: users_id(options)['user']['id']) if options[:user]
  if block_given?
    Pagination::Cursor.new(self, :team_billableInfo, options).each do |page|
      yield page
    end
  else
    post('team.billableInfo', options)
  end
end

#team_info(options = {}) ⇒ Object

Gets information about the current team.

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :domain (string)

    Query by domain instead of team (only when team is null). This only works for domains in the same enterprise as the querying team token. This also expects the domain to belong to a team and not the enterprise itself.

  • :team (string)

    Team to get info on, if omitted, will return information about the current team. Will only return team that the authenticated token is allowed to see through external shared channels.

See Also:



55
56
57
# File 'lib/slack/web/api/endpoints/team.rb', line 55

def team_info(options = {})
  post('team.info', options)
end

#team_integrationLogs(options = {}) ⇒ Object

Gets the integration logs for the current team.

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :app_id (string)

    Filter logs to this Slack app. Defaults to all logs.

  • :change_type (string)

    Filter logs with this change type. Defaults to all logs.

  • :service_id (string)

    Filter logs to this service. Defaults to all logs.

  • :team_id (string)

    encoded team id to get logs from, required if org token is used.

  • :user (user)

    Filter logs generated by this user’s actions. Defaults to all logs.

See Also:



74
75
76
77
# File 'lib/slack/web/api/endpoints/team.rb', line 74

def team_integrationLogs(options = {})
  options = options.merge(user: users_id(options)['user']['id']) if options[:user]
  post('team.integrationLogs', options)
end