Method: Slack::Web::Api::Endpoints::Groups#groups_list
- Defined in:
- lib/slack/web/api/endpoints/groups.rb
#groups_list(options = {}) ⇒ Object
This method returns a list of private channels in the team that the caller is in and archived groups that the caller was in. The list of (non-deactivated) members in each private channel is also returned.
150 151 152 |
# File 'lib/slack/web/api/endpoints/groups.rb', line 150 def groups_list( = {}) post('groups.list', ) end |