Module: Slack::Web::Api::Endpoints::AppsManifest
- Included in:
- Slack::Web::Api::Endpoints
- Defined in:
- lib/slack/web/api/endpoints/apps_manifest.rb
Instance Method Summary collapse
-
#apps_manifest_create(options = {}) ⇒ Object
Create an app from an app manifest.
-
#apps_manifest_delete(options = {}) ⇒ Object
Permanently deletes an app created through app manifests.
-
#apps_manifest_export(options = {}) ⇒ Object
Export an app manifest from an existing app.
-
#apps_manifest_update(options = {}) ⇒ Object
Update an app from an app manifest.
-
#apps_manifest_validate(options = {}) ⇒ Object
Validate an app manifest.
Instance Method Details
#apps_manifest_create(options = {}) ⇒ Object
Create an app from an app manifest.
18 19 20 21 22 |
# File 'lib/slack/web/api/endpoints/apps_manifest.rb', line 18 def apps_manifest_create( = {}) raise ArgumentError, 'Required arguments :manifest missing' if [:manifest].nil? = (, %i[manifest]) post('apps.manifest.create', ) end |
#apps_manifest_delete(options = {}) ⇒ Object
Permanently deletes an app created through app manifests. When called with a manager app token, this method can only delete apps that were created by that manager app.
31 32 33 34 |
# File 'lib/slack/web/api/endpoints/apps_manifest.rb', line 31 def apps_manifest_delete( = {}) raise ArgumentError, 'Required arguments :app_id missing' if [:app_id].nil? post('apps.manifest.delete', ) end |
#apps_manifest_export(options = {}) ⇒ Object
Export an app manifest from an existing app. When called with a manager app token, this method can only export apps that were created by that manager app.
43 44 45 46 |
# File 'lib/slack/web/api/endpoints/apps_manifest.rb', line 43 def apps_manifest_export( = {}) raise ArgumentError, 'Required arguments :app_id missing' if [:app_id].nil? post('apps.manifest.export', ) end |
#apps_manifest_update(options = {}) ⇒ Object
Update an app from an app manifest. When called with a manager app token, this method can only update apps that were created by that manager app.
57 58 59 60 61 62 |
# File 'lib/slack/web/api/endpoints/apps_manifest.rb', line 57 def apps_manifest_update( = {}) raise ArgumentError, 'Required arguments :manifest missing' if [:manifest].nil? raise ArgumentError, 'Required arguments :app_id missing' if [:app_id].nil? = (, %i[manifest]) post('apps.manifest.update', ) end |
#apps_manifest_validate(options = {}) ⇒ Object
Validate an app manifest
73 74 75 76 |
# File 'lib/slack/web/api/endpoints/apps_manifest.rb', line 73 def apps_manifest_validate( = {}) raise ArgumentError, 'Required arguments :manifest missing' if [:manifest].nil? post('apps.manifest.validate', ) end |