Module: Slack::Web::Api::Endpoints::AppsUserConnection
- Included in:
- Slack::Web::Api::Endpoints
- Defined in:
- lib/slack/web/api/endpoints/apps_user_connection.rb
Instance Method Summary collapse
-
#apps_user_connection_update(options = {}) ⇒ Object
Updates the connection status between a user and an app.
Instance Method Details
#apps_user_connection_update(options = {}) ⇒ Object
Updates the connection status between a user and an app.
18 19 20 21 22 |
# File 'lib/slack/web/api/endpoints/apps_user_connection.rb', line 18 def apps_user_connection_update( = {}) raise ArgumentError, 'Required arguments :user_id missing' if [:user_id].nil? raise ArgumentError, 'Required arguments :status missing' if [:status].nil? post('apps.user.connection.update', ) end |